import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:sudoku/config/default_game_settings.dart';
import 'package:sudoku/models/settings/settings_game.dart';

part 'settings_game_state.dart';

class GameSettingsCubit extends HydratedCubit<GameSettingsState> {
  GameSettingsCubit() : super(GameSettingsState(settings: GameSettings.createDefault()));

  void setValues({
    String? level,
    String? size,
  }) {
    emit(
      GameSettingsState(
        settings: GameSettings(
          level: level ?? state.settings.level,
          size: size ?? state.settings.size,
        ),
      ),
    );
  }

  String getParameterValue(String code) {
    switch (code) {
      case DefaultGameSettings.parameterCodeLevel:
        return GameSettings.getLevelValueFromUnsafe(state.settings.level);
      case DefaultGameSettings.parameterCodeSize:
        return GameSettings.getSizeValueFromUnsafe(state.settings.size);
    }

    return '';
  }

  void setParameterValue(String code, String value) {
    final String level = (code == DefaultGameSettings.parameterCodeLevel)
        ? value
        : getParameterValue(DefaultGameSettings.parameterCodeLevel);
    final String size = (code == DefaultGameSettings.parameterCodeSize)
        ? value
        : getParameterValue(DefaultGameSettings.parameterCodeSize);

    setValues(
      level: level,
      size: size,
    );
  }

  @override
  GameSettingsState? fromJson(Map<String, dynamic> json) {
    final String level = json[DefaultGameSettings.parameterCodeLevel] as String;
    final String size = json[DefaultGameSettings.parameterCodeSize] as String;

    return GameSettingsState(
      settings: GameSettings(
        level: level,
        size: size,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(GameSettingsState state) {
    return <String, dynamic>{
      DefaultGameSettings.parameterCodeLevel: state.settings.level,
      DefaultGameSettings.parameterCodeSize: state.settings.size,
    };
  }
}
