import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:sudoku/cubit/game_cubit.dart';
import 'package:sudoku/models/game/cell.dart';
import 'package:sudoku/models/game/game.dart';

class CellWidgetUpdate extends StatelessWidget {
  const CellWidgetUpdate({super.key, this.cell});

  final Cell? cell;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game game = gameState.currentGame;

        if ((cell?.value ?? 0) < 0) {
          return Container();
        }

        final String imageAsset = getImageAssetName(game);

        Color backgroundColor = Colors.grey.shade200;

        if (game.showConflicts == true &&
            game.selectedCell?.location.col != null &&
            game.selectedCell?.location.row != null) {
          if (!game.board.isValueAllowed(game.selectedCell?.location, cell?.value ?? 0)) {
            backgroundColor = Colors.pink.shade100;
          }
        }

        return Container(
          decoration: BoxDecoration(
            color: backgroundColor,
            border: Border.all(
              color: Colors.grey.shade700,
              width: 2,
            ),
          ),
          child: GestureDetector(
            child: Image(image: AssetImage(imageAsset), fit: BoxFit.fill),
            onTap: () {
              final GameCubit gameCubit = BlocProvider.of<GameCubit>(context);

              if (game.selectedCell != null) {
                gameCubit.updateCellValue(game.selectedCell!.location, cell?.value ?? 0);
              }

              gameCubit.unselectCell();
            },
          ),
        );
      },
    );
  }

  /*
  * Compute image asset name, from skin and cell value/state
  */
  String getImageAssetName(Game game) {
    if ((cell?.value ?? 0) > 0) {
      final int cellValue = game.getTranslatedValueForDisplay(cell?.value ?? 0);
      return 'assets/skins/${game.globalSettings.skin}_$cellValue.png';
    }

    return 'assets/ui/cell_empty.png';
  }
}
